<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/About.qml" line="27"/>
        <source>Add new media</source>
        <translation>Ajouter un média</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="46"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="68"/>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="87"/>
        <source>Webcam capture application.</source>
        <translation>Application de capture de webcam.</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="90"/>
        <source>A simple webcam application for picture and video capture.</source>
        <translation>Un logiciel de webcam simple pour la capture d&apos;images et de vidéo.</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="79"/>
        <source>Website</source>
        <translation>Site web</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="72"/>
        <source>Using Qt %1 with %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="104"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="115"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>AddMedia</name>
    <message>
        <location filename="../qml/AddMedia.qml" line="28"/>
        <source>Add new media</source>
        <translation>Ajouter un média</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="65"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="72"/>
        <source>Insert media description</source>
        <translation>Insérer la description du média</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="79"/>
        <source>Media file</source>
        <translation>Fichier média</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="87"/>
        <source>Select media file</source>
        <translation>Sélectionnez un fichier multimédia</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="94"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="116"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="139"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="150"/>
        <source>Choose the file to add as media</source>
        <translation>Choisissez le fichier à ajouter comme média</translation>
    </message>
</context>
<context>
    <name>AudioConfig</name>
    <message>
        <location filename="../qml/AudioConfig.qml" line="38"/>
        <source>Record audio from</source>
        <translation>Enregistrer l&apos;audio à partir de</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="46"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="56"/>
        <source>Mic</source>
        <translation>Micro</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="66"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="77"/>
        <source>Play audio from source</source>
        <translation type="unfinished">Lire l&apos;audio de la source</translation>
    </message>
</context>
<context>
    <name>BusyIndicatorSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/BusyIndicatorSpecifics.qml" line="46"/>
        <source>Busy Indicator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/BusyIndicatorSpecifics.qml" line="50"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/BusyIndicatorSpecifics.qml" line="51"/>
        <source>Whether the busy indicator is currently indicating activity.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ButtonSection</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="46"/>
        <source>Text</source>
        <translation type="unfinished">Texte</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="47"/>
        <source>The text displayed on the %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="57"/>
        <source>Highlighted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="58"/>
        <source>Whether the %1 is highlighted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="70"/>
        <source>Checkable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="71"/>
        <source>Whether the %1 is checkable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="82"/>
        <source>Checked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="83"/>
        <source>Whether the %1 is checked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="94"/>
        <source>Exclusive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="95"/>
        <source>Whether the %1 is exclusive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="106"/>
        <source>Repeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSection.qml" line="107"/>
        <source>Whether the %1 repeats while pressed and held down.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ButtonSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ButtonSpecifics.qml" line="45"/>
        <source>Button</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CheckBoxSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/CheckBoxSpecifics.qml" line="45"/>
        <source>Check Box</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CircularGaugeSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="48"/>
        <source>CircularGauge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="52"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="53"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="66"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="67"/>
        <source>Minimum Value</source>
        <translation>Valeur minimale</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="81"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="82"/>
        <source>Maximum Value</source>
        <translation>Valeur maximale</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="96"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/CircularGaugeSpecifics.qml" line="97"/>
        <source>Step Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComboBoxSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ComboBoxSpecifics.qml" line="46"/>
        <source>Combo Box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ComboBoxSpecifics.qml" line="50"/>
        <source>Text Role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ComboBoxSpecifics.qml" line="51"/>
        <source>The model role used for displaying text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ComboBoxSpecifics.qml" line="61"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ComboBoxSpecifics.qml" line="62"/>
        <source>The index of the current item.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigBar</name>
    <message>
        <location filename="../qml/ConfigBar.qml" line="44"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="48"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="52"/>
        <source>General Options</source>
        <translation>Options générales</translation>
    </message>
</context>
<context>
    <name>ControlSection</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ControlSection.qml" line="42"/>
        <source>Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ControlSection.qml" line="46"/>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ControlSection.qml" line="47"/>
        <source>Whether the control is enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ControlSection.qml" line="58"/>
        <source>Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ControlSection.qml" line="59"/>
        <source>Spacing between internal elements of the control.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DelayButtonSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DelayButtonSpecifics.qml" line="48"/>
        <source>DelayButton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DelayButtonSpecifics.qml" line="52"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DelayButtonSpecifics.qml" line="53"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DelayButtonSpecifics.qml" line="79"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DelayButtonSpecifics.qml" line="80"/>
        <source>Delay</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="46"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="48"/>
        <source>Dial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="50"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="52"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="53"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="51"/>
        <source>The current value of the dial.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="64"/>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="65"/>
        <source>The starting value of the dial range.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="78"/>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="79"/>
        <source>The ending value of the dial range.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="93"/>
        <source>The step size of the dial.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="68"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="69"/>
        <source>Minimum Value</source>
        <translation>Valeur minimale</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="84"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="85"/>
        <source>Maximum Value</source>
        <translation>Valeur maximale</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/DialSpecifics.qml" line="92"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="100"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="101"/>
        <source>Step Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="116"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/DialSpecifics.qml" line="117"/>
        <source>Tickmarks Visible</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMenu_base</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="48"/>
        <source>&amp;Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="59"/>
        <source>&amp;Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="70"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="84"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="98"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="109"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="120"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Controls/Private/EditMenu_base.qml" line="131"/>
        <source>Select All</source>
        <translation>Sélectionner tout</translation>
    </message>
</context>
<context>
    <name>EffectBar</name>
    <message>
        <location filename="../qml/EffectBar.qml" line="110"/>
        <source>Search effect...</source>
        <translation>Rechercher un effet...</translation>
    </message>
    <message>
        <location filename="../qml/EffectBar.qml" line="156"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>EffectConfig</name>
    <message>
        <location filename="../qml/EffectConfig.qml" line="53"/>
        <location filename="../qml/EffectConfig.qml" line="60"/>
        <source>Plugin id</source>
        <translation>Id du plugin</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="66"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="73"/>
        <source>Plugin description</source>
        <translation>Description du plugin</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="88"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="88"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
</context>
<context>
    <name>GaugeSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/GaugeSpecifics.qml" line="48"/>
        <source>Gauge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/GaugeSpecifics.qml" line="53"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/GaugeSpecifics.qml" line="54"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/GaugeSpecifics.qml" line="69"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/GaugeSpecifics.qml" line="70"/>
        <source>Minimum Value</source>
        <translation>Valeur minimale</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/GaugeSpecifics.qml" line="85"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/GaugeSpecifics.qml" line="86"/>
        <source>Maximum Value</source>
        <translation>Valeur maximale</translation>
    </message>
</context>
<context>
    <name>GeneralConfig</name>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="26"/>
        <source>Enable advanced effects mode</source>
        <translation>Activer le mode effets avancés</translation>
    </message>
</context>
<context>
    <name>GroupBoxSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/GroupBoxSpecifics.qml" line="46"/>
        <source>Group Box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/GroupBoxSpecifics.qml" line="50"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/GroupBoxSpecifics.qml" line="51"/>
        <source>The title of the group box.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ItemDelegateSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ItemDelegateSpecifics.qml" line="45"/>
        <source>Item Delegate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConfig</name>
    <message>
        <location filename="../qml/MediaConfig.qml" line="48"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="55"/>
        <source>Insert media description</source>
        <translation>Insérer la description du média</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="62"/>
        <source>Media file</source>
        <translation>Fichier multimédia</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="69"/>
        <source>Select media file</source>
        <translation>Sélectionnez le fichier multimédia</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="84"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="93"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>OutputConfig</name>
    <message>
        <location filename="../qml/OutputConfig.qml" line="39"/>
        <source>Virtual camera</source>
        <translation>Camera virtuelle</translation>
    </message>
</context>
<context>
    <name>PaddingSection</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="42"/>
        <source>Padding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="46"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="47"/>
        <source>Padding between the content and the top edge of the control.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="60"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="61"/>
        <source>Padding between the content and the left edge of the control.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="74"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="75"/>
        <source>Padding between the content and the right edge of the control.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="88"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PaddingSection.qml" line="89"/>
        <source>Padding between the content and the bottom edge of the control.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageIndicatorSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PageIndicatorSpecifics.qml" line="46"/>
        <source>Indicator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PageIndicatorSpecifics.qml" line="50"/>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PageIndicatorSpecifics.qml" line="51"/>
        <source>The number of pages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PageIndicatorSpecifics.qml" line="64"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/PageIndicatorSpecifics.qml" line="65"/>
        <source>The index of the current page.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhotoWidget</name>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="35"/>
        <source>%1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="55"/>
        <source>Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="79"/>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="79"/>
        <source>Shot!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="106"/>
        <source>Use flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PictureBox</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/PictureBox.qml" line="123"/>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PictureSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PictureSpecifics.qml" line="50"/>
        <source>Picture</source>
        <translation>Photo</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PictureSpecifics.qml" line="54"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PictureSpecifics.qml" line="55"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PictureSpecifics.qml" line="71"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PictureSpecifics.qml" line="74"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
</context>
<context>
    <name>PieMenuSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PieMenuSpecifics.qml" line="50"/>
        <source>PieMenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PieMenuSpecifics.qml" line="54"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/PieMenuSpecifics.qml" line="55"/>
        <source>Trigger Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProgressBarSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="46"/>
        <source>Progress Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="50"/>
        <source>Indeterminate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="51"/>
        <source>Whether the progress is indeterminate.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="62"/>
        <source>Value</source>
        <translation type="unfinished">Valeur</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="63"/>
        <source>The current value of the progress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="76"/>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="77"/>
        <source>The starting value for the progress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="90"/>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ProgressBarSpecifics.qml" line="91"/>
        <source>The ending value for the progress.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RadioButtonSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/RadioButtonSpecifics.qml" line="45"/>
        <source>Radio Button</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordBar</name>
    <message>
        <location filename="../qml/RecordBar.qml" line="106"/>
        <source>Search format...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordConfig</name>
    <message>
        <location filename="../qml/RecordConfig.qml" line="69"/>
        <source>Video %1.%2</source>
        <translation>Vidéo %1. %2</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="78"/>
        <source>Stop recording video</source>
        <translation>Arrêter l&apos;enregistrement vidéo</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="81"/>
        <location filename="../qml/RecordConfig.qml" line="114"/>
        <source>Start recording video</source>
        <translation>Démarrer l&apos;enregistrement vidéo</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="93"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="100"/>
        <source>Insert format description</source>
        <translation>Insérer la description du format</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="178"/>
        <source>Save video as...</source>
        <translation>Sauvegarder la vidéo en tant que...</translation>
    </message>
</context>
<context>
    <name>SliderSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="46"/>
        <source>Slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="50"/>
        <source>Value</source>
        <translation type="unfinished">Valeur</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="51"/>
        <source>The current value of the slider.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="64"/>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="65"/>
        <source>The starting value of the slider range.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="78"/>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="79"/>
        <source>The ending value of the slider range.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="92"/>
        <source>Step Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="93"/>
        <source>The step size of the slider.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="106"/>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SliderSpecifics.qml" line="107"/>
        <source>The orientation of the slider.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpinBoxSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="46"/>
        <source>Spin Box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="50"/>
        <source>Value</source>
        <translation type="unfinished">Valeur</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="51"/>
        <source>The current value of the spinbox.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="64"/>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="65"/>
        <source>The starting value of the spinbox range.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="78"/>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="79"/>
        <source>The ending value of the spinbox range.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="92"/>
        <source>Step Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SpinBoxSpecifics.qml" line="93"/>
        <source>The step size of the spinbox.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIndicatorSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/StatusIndicatorSpecifics.qml" line="48"/>
        <source>StatusIndicator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/StatusIndicatorSpecifics.qml" line="52"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/StatusIndicatorSpecifics.qml" line="53"/>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/StatusIndicatorSpecifics.qml" line="68"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/StatusIndicatorSpecifics.qml" line="71"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
</context>
<context>
    <name>SwitchSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/SwitchSpecifics.qml" line="45"/>
        <source>Switch</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="28"/>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Attention, Verr Maj est activée !</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="29"/>
        <source>Layout</source>
        <translation>Mise en page</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="30"/>
        <source>Login</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="31"/>
        <source>Login failed</source>
        <translation>La connexion a échoué</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="32"/>
        <source>Login succeeded</source>
        <translation>La connexion a réussi</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="33"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="34"/>
        <source>Enter your username and password</source>
        <translation>Entrez votre nom d&apos;utilisateur et votre mot de passe</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="35"/>
        <source>Select your user and enter password</source>
        <translation>Sélectionnez votre nom d&apos;utilisateur et entrez votre mot de passe</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="36"/>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="37"/>
        <source>Session</source>
        <translation>Session</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="38"/>
        <source>Shutdown</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="39"/>
        <source>User name</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/SddmComponents/TextConstants.qml" line="40"/>
        <source>Welcome to %1</source>
        <translation>Bienvenue sur %1</translation>
    </message>
</context>
<context>
    <name>ToggleButtonSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/ToggleButtonSpecifics.qml" line="48"/>
        <source>ToggleButton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/ToggleButtonSpecifics.qml" line="52"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/ToggleButtonSpecifics.qml" line="53"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/ToggleButtonSpecifics.qml" line="79"/>
        <location filename="../../../../../../../../../usr/lib/qt/qml/QtQuick/Extras/designer/ToggleButtonSpecifics.qml" line="80"/>
        <source>Checked</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolButtonSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/ToolButtonSpecifics.qml" line="45"/>
        <source>Tool Button</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TumblerSpecifics</name>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/TumblerSpecifics.qml" line="46"/>
        <source>Tumbler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/TumblerSpecifics.qml" line="50"/>
        <source>Visible Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/TumblerSpecifics.qml" line="51"/>
        <source>The count of visible items.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/TumblerSpecifics.qml" line="64"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../../../../../../usr/lib/qt/qml/Qt/labs/controls/designer/TumblerSpecifics.qml" line="65"/>
        <source>The index of the current item.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="108"/>
        <source>Recording</source>
        <translation>Enregistrement en cours</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="518"/>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="540"/>
        <source>Configure streams</source>
        <translation>Configurer les flux</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="553"/>
        <source>Take a photo</source>
        <translation>Prendre une photo</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="188"/>
        <source>Picture %1.%2</source>
        <translation>Photo %1. %2</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="472"/>
        <source>Go back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="567"/>
        <source>Record video</source>
        <translation>Enregistrer la vidéo</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="581"/>
        <source>Configure Effects</source>
        <translation>Configurer les effets</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="594"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="607"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="197"/>
        <source>Save photo as...</source>
        <translation>Enregistrer la photo sous...</translation>
    </message>
</context>
</TS>
